@@ -12,8 +12,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (3)
-#define SOUP_MINOR_VERSION (4)
-#define SOUP_MICRO_VERSION (5)
+#define SOUP_MINOR_VERSION (6)
+#define SOUP_MICRO_VERSION (0)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -72,6 +72,15 @@ G_BEGIN_DECLS
  * Since: 3.4
  */
 #define SOUP_VERSION_3_4 (G_ENCODE_VERSION (3, 4))
+/**
+ * SOUP_VERSION_3_6:
+ *
+ * A macro that evaluates to the 3.6 version of libsoup, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 3.6
+ */
+#define SOUP_VERSION_3_6 (G_ENCODE_VERSION (3, 6))
 
 
 /* evaluates to the current stable version; for development cycles,
@@ -247,6 +256,33 @@ G_BEGIN_DECLS
 #else
 # define SOUP_AVAILABLE_IN_3_4                 _SOUP_EXTERN
 #endif
+/**
+ * SOUP_DEPRECATED_IN_3_6:
+ * A macro used to indicate a symbol was deprecated in this version.
+ */
+/**
+ * SOUP_DEPRECATED_IN_3_6_FOR:
+ * @f: The recommended replacement function.
+ *
+ * A macro used to indicate a symbol was deprecated in this version with a replacement.
+ */
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_3_6
+# define SOUP_DEPRECATED_IN_3_6                SOUP_DEPRECATED
+# define SOUP_DEPRECATED_IN_3_6_FOR(f)         SOUP_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_3_6                _SOUP_EXTERN
+# define SOUP_DEPRECATED_IN_3_6_FOR(f)         _SOUP_EXTERN
+#endif
+
+/**
+ * SOUP_AVAILABLE_IN_3_6:
+ * A macro used to indicate a symbol is available in this version or later.
+ */
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_3_6
+# define SOUP_AVAILABLE_IN_3_6                 SOUP_UNAVAILABLE(3, 6)
+#else
+# define SOUP_AVAILABLE_IN_3_6                 _SOUP_EXTERN
+#endif
 
 
 SOUP_AVAILABLE_IN_ALL
